DioInterceptor class
Dio interceptor that logs network requests and responses to the NetworkInspector.
This interceptor automatically captures all HTTP requests made through Dio and logs them to the database for later inspection. It provides detailed logging including headers, bodies, timing, and error information.
Constructors
- DioInterceptor({bool logIsAllowed = true, bool isConsoleLogAllowed = true, OnHttpFinish? onHttpFinish})
- Creates a new DioInterceptor instance.
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- isConsoleLogAllowed → bool
-
final
- logIsAllowed → bool
-
final
- onHttpFinish → OnHttpFinish?
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
onError(
DioException err, ErrorInterceptorHandler handler) → void - Called when an exception was occurred during the request.
-
onRequest(
RequestOptions options, RequestInterceptorHandler handler) → void - Called when a request is about to be sent.
-
onResponse(
Response response, ResponseInterceptorHandler handler) → void - Called when the response is about to be resolved.
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited